@@ -549,9 +549,9 @@ schemes = {
             'auId': lambda x: x.get('auId'),
             'email': lambda x: x.get('email'),
             'name': lambda x: x.get('name'),
-            'isVip': lambda x: x.get('isVip'),
-            'isCommunity': lambda x: x.get('isCommunity'),
-            'isVideoChannel': lambda x: x.get('isVideoChannel'),
+            'is_vip': lambda x: x.get('isVip'),
+            'is_community': lambda x: x.get('isCommunity'),
+            'is_video_channel': lambda x: x.get('isVideoChannel'),
         }
     },
     'Behance': {
@@ -695,11 +695,23 @@ schemes = {
         'flags': ['https://api.bitbucket.org'],
         'regex': r'({.+?"section": {"profile.+?"whats_new_feed":.+?}});',
         'extract_json': True,
+        'transforms': [
+            json.loads,
+            lambda x: x['global']['targetUser'],
+            json.dumps,
+        ],
         'fields': {
-            'uid': lambda x: x['global']['targetUser']['uuid'].strip('{}'),
-            'username': lambda x: x['global']['targetUser']['nickname'],
-            'created_at': lambda x: x['global']['targetUser']['created_on'],
-            'is_service': lambda x: x['global']['targetUser']['is_staff'],
+            'uid': lambda x: x['uuid'].strip('{}'),
+            'id': lambda x: x['account_id'],
+            'fullname': lambda x: x['display_name'],
+            'nickname': lambda x: x['nickname'],
+            'location': lambda x: x['location'],
+            'image': lambda x: x['links']['avatar']['href'],
+            'occupation': lambda x: x['job_title'],
+            'created_at': lambda x: x['created_on'],
+            'is_service': lambda x: x['is_staff'],
+            'is_active': lambda x: x['is_active'],
+            'has_2fa_enabled': lambda x: x['has_2fa_enabled'],
         }
     },
     'Pinterest API': {
@@ -1294,5 +1306,75 @@ schemes = {
             'image': lambda x: 'https://distro.tapd.co/' + x['header']['picture'],
             'links': lambda x: [l['url'].strip() for l in x['links']],
         }
+    },
+    'freelancer.com': {
+        'flags': ['{"status":"success","result":{"users":{'],
+        'regex': r'^([\s\S]+)$',
+        'extract_json': True,
+        'url_mutations': [
+            {
+                'from': r'https?://(www.)?freelancer\.com/u/(?P<username>[^/]+).*',
+                'to': 'https://www.freelancer.com/api/users/0.1/users?usernames%5B%5D={username}&compact=true',
+            }
+        ],
+        'transforms': [
+            json.loads,
+            lambda x: list(x['result']['users'].values())[0],
+            json.dumps,
+        ],
+        'fields': {
+            'id': lambda x: x['id'],
+            'nickname': lambda x: x['display_name'],
+            'username': lambda x: x['username'],
+            'fullname': lambda x: x['public_name'],
+            'company': lambda x: x['company'],
+            'company_founder_id': lambda x: x['corporate']['founder_id'],
+            'role': lambda x: x['role'],
+            'location': lambda x: x['location']['city'] + ', ' + x['location']['country']['name'],
+            'created_at': lambda x: timestamp_to_datetime(x['registration_date']),
+        }
+    },
+    'Yelp': {
+        'flags': ['yelp.www.init.user_details'],
+        'bs': True,
+        'fields': {
+            'yelp_userid': lambda x: x.find('meta', {'property': 'og:url'}).get('content').split('=')[-1],
+            'fullname': lambda x: x.find('div', {'class': 'user-profile_info'}).find('h1').contents[0],
+            'location': lambda x: x.find('div', {'class': 'user-profile_info'}).find('h3').contents[0].split(' ', 1)[1],
+            'image': lambda x: x.find('div', {'class': 'user-profile_avatar'}).find('img').get('src'),
+        }
+    },
+    'Trello API': {
+        'flags': ['"aaId"', '"trophies":'],
+        'regex': r'^([\s\S]+)$',
+        'extract_json': True,
+        'fields': {
+            'id': lambda x: x['id'],
+            'username': lambda x: x['username'],
+            'fullname': lambda x: x['fullName'],
+            'email': lambda x: x['email'],
+            'image': lambda x: x['avatarUrl'] + '/170.png',
+            'bio': lambda x: x['bio'],
+            'type': lambda x: x['memberType'],
+            'gravatar_email_md5_hash': lambda x: x['gravatarHash'],
+            'is_verified': lambda x: x['confirmed'],
+        }
+    },
+    'Weibo': {
+        'flags': ['$CONFIG[\'timeweibo\']'],
+        'regex': r'\$CONFIG = {};[\r\n]([\s\S]+?)</script>',
+        'transforms': [
+            lambda x: re.split('[\r\n]', x),
+            lambda x: [r.split("'") for r in x if r],
+            lambda x: {r[1]: r[-2] for r in x},
+        ],
+        'fields': {
+            'weibo_id': lambda x: x['oid'],
+            'fullname': lambda x: x['onick'],
+            'nickname': lambda x: x['nick'],
+            'image': lambda x: x['avatar_large'],
+            'gender': lambda x: x['sex'],
+            'language': lambda x: x['lang'],
+        }
     }
 }
